@@ -41,7 +41,7 @@ inode()
 	if (argcnt > optind) {
 		if (!full) mprintf(head_inode);
 		for (i = optind; i < argcnt; i++) {
-			addr = getaddr(args[i]);
+			addr = getvalue(args[i]);
 			if (full) mprintf(head_inode);
 			addr = print_inode(addr, full);
 		}
