@@ -34,7 +34,7 @@ vfsmount()
 		}
 	} else {
 		for (i = optind; i < argcnt; i++) {
-			addr = getaddr(args[i]);
+			addr = getvalue(args[i]);
 			addr = print_vfsmount(addr, 0);
 		}
 	}
