@@ -53,19 +53,33 @@ print_zone(addr, full)
 	}
 
 	mprintf("free_pages         %lx\n", zone.free_pages);
+
 #if SUBLEVEL<10
 	mprintf("inactive_clean_pages %lx\n", zone.inactive_clean_pages);
 	mprintf("inactive_dirty_pages %lx\n", zone.inactive_dirty_pages);
 #endif
+
+#if SUBLEVEL>=23
+	for (i = 0; i < MAX_NR_ZONES; i++) {
+		mprintf("watermarks[%2d]     %x/%x/%x\n",
+			zone.watermarks[i].min,
+			zone.watermarks[i].low,
+			zone.watermarks[i].high);
+	}
+#else
 	mprintf("pages_min/low/high %lx/%lx/%lx\n",
 		zone.pages_min, zone.pages_low, zone.pages_high);
+#endif
+
 #if SUBLEVEL>=10
 	mprintf("need_balance       %x\n", zone.need_balance);
 #endif
+
 #if SUBLEVEL<10
 	mprintf("inactive_clean_list " FPTR " " FPTR "\n",
 		zone.inactive_clean_list.next, zone.inactive_clean_list.prev);
 #endif
+
 	mprintf("FREE " SPTR " " SPTR "  " SPTR "\n", "NEXT", "PREV", "MAP");
 	for (i = 0; i < MAX_ORDER; i++) {
 		free_area_t *fp = &zone.free_area[i];
