@@ -46,10 +46,28 @@ int full;
 		mprintf("\n");
 	}
 	if (full) {
-		mprintf("  " FPTR " " FPTR, m.ex_table_start, m.ex_table_end);
-		mprintf("  " FPTR " " FPTR, m.kallsyms_start, m.kallsyms_end);
-		mprintf("  " FPTR " " FPTR, m.archdata_start, m.archdata_end);
-		mprintf("\n");
+		int i;
+		struct module_symbol msym;
+		char buf[256];
+
+		mprintf("  ex_table " FPTR " " FPTR "\n",
+			m.ex_table_start, m.ex_table_end);
+		mprintf("  persist  " FPTR " " FPTR "\n",
+			m.persist_start,  m.persist_end);
+		mprintf("  kallsyms " FPTR " " FPTR "\n",
+			m.kallsyms_start, m.kallsyms_end);
+		mprintf("  archdata " FPTR " " FPTR "\n",
+			m.archdata_start, m.archdata_end);
+
+		for (i = 0; i < m.nsyms; i++) {
+			memread((addr_t)m.syms + sizeof(msym) * i, sizeof(msym), &msym, "module_symbol");
+			if (msym.name == 0)
+				continue;
+			memread((addr_t)msym.name, sizeof(buf), buf, "symbol name");
+			mprintf("  ");
+			mprintstr(buf, sizeof(buf));
+			mprintf("\t%lx\n", msym.value);
+		}
 	}
 	return (addr_t)m.next;
 }
