@@ -8,9 +8,9 @@
 
 PRIVATE addr_t csocket(), sock();
 const commandtable_t command_socket =
-	{"socket", csocket, "", "print socket table"};
+	{"socket", csocket, "address", "print socket table"};
 const commandtable_t command_sock =
-	{"sock", sock, "", "print sock table"};
+	{"sock", sock, "[address]", "print sock table"};
 
 extern addr_t print_socket();
 extern addr_t print_sock();
@@ -35,7 +35,7 @@ csocket()
 	for (i = optind; i < argcnt; i++) {
 		if (i > optind)
 			mprintf("\n");
-		addr = getaddr(args[i]);
+		addr = getvalue(args[i]);
 		print_socket(addr);
 	}
 	return 0;
@@ -69,7 +69,7 @@ sock()
 	for (i = optind; i < argcnt; i++) {
 		if (i > optind)
 			mprintf("\n");
-		addr = getaddr(args[i]);
+		addr = getvalue(args[i]);
 		addr = print_sock(addr, fflag);
 	}
 	return addr;
