@@ -590,16 +590,22 @@ print_file_lock(addr, full, chain)
 			mprintf(SPTR " " SPTR "\n", "-", "-");
 		} else {
 			mprintf(FPTR " " FPTR "\n",
-			fl.fl_block.next, fl.fl_block.prev);
+				(addr_t)fl.fl_block.next - OFFSET(struct file_lock, fl_block),
+				(addr_t)fl.fl_block.prev - OFFSET(struct file_lock, fl_block));
 		}
+#if 1
+		mprintf("  wait:       " FPTR "  (wait_queue_head)\n",
+			addr + OFFSET(struct file_lock, fl_wait));
+#else
 		mprintf("  wait:       ");
 		if ((addr_t)fl.fl_wait.task_list.next == addr + OFFSET(struct file_lock, fl_wait.task_list)) {
 			mprintf(SPTR " " SPTR "\n", "-", "-");
 		} else {
 			mprintf(FPTR " " FPTR "\n",
-				fl.fl_wait.task_list.prev,
-				fl.fl_wait.task_list.next);
+				fl.fl_wait.task_list.next,
+				fl.fl_wait.task_list.prev);
 		}
+#endif
 		mprintf("  not/ins/rem:" FPTR " " FPTR " " FPTR "\n",
 			fl.fl_notify, fl.fl_insert, fl.fl_remove);
 		mprintf("  fasync:     " FPTR "\n", fl.fl_fasync);
