@@ -94,20 +94,25 @@ print_nfs_inode(addr, full, iflag)
 
 	if (full) {
 		mprint_nfs_fh(&ni.fh);
-		mprintf("read_cache_jiffies   %lx\n", ni.read_cache_jiffies);
-		mprintf("read_cache_ctime     %lx\n", ni.read_cache_ctime.tv_sec);
-		mprintf("read_cache_mtime     %lx\n", ni.read_cache_mtime.tv_sec);
-		mprintf("read_cache_isize     %llx\n", ni.read_cache_isize);
-		mprintf("attrtimeo            %lx\n", ni.attrtimeo);
-		mprintf("attrtimeo_timestamp  %lx\n", ni.attrtimeo_timestamp);
-		mprintf("cache_mtime_jiffies  %lx\n", ni.cache_mtime_jiffies);
-		mprintf("cache_access.jiffies %lx\n", ni.cache_access.jiffies);
-		mprintf("cache_access.cred    "FPTR"\n", ni.cache_access.cred);
-		mprintf("cache_access.mask    %x\n", ni.cache_access.mask);
-		mprintf("cache_access.err     %x\n", ni.cache_access.err);
-		mprintf("cookieverf           %x  %x\n",
+#ifdef _nfs_inode_has_readdir_timestamp
+		mprintf("readdir_timestamp      %lx\n", ni.readdir_timestamp);
+#endif
+		mprintf("read_cache_jiffies     %lx\n", ni.read_cache_jiffies);
+		mprintf("attrtimeo              %lx\n", ni.attrtimeo);
+		mprintf("attrtimeo_timestamp    %lx\n", ni.attrtimeo_timestamp);
+#ifdef _nfs_inode_has_cache_change_attribute
+		mprintf("cache_change_attribute %lx\n", ni.cache_change_attribute);
+#endif
+#ifdef _nfs_inode_has_data_updates
+		mprintf("data_updates           %x\n",  ATOMIC_READ(ni.data_updates));
+#endif
+		mprintf("cache_access.jiffies   %lx\n", ni.cache_access.jiffies);
+		mprintf("cache_access.cred      "FPTR"\n", ni.cache_access.cred);
+		mprintf("cache_access.mask      %x\n", ni.cache_access.mask);
+		mprintf("cache_access.err       %x\n", ni.cache_access.err);
+		mprintf("cookieverf             %x  %x\n",
 					ni.cookieverf[0], ni.cookieverf[1]);
-		mprintf("mm_cred              " FPTR "\n", ni.mm_cred);
+		mprintf("mm_cred                " FPTR "\n", ni.mm_cred);
 	}
 
 	return (addr_t)ni.dirty.next - OFFSET(struct nfs_inode, dirty);
