@@ -7,6 +7,12 @@
 #define __KERNEL__
 #include <linux/param.h>
 
+void
+mprint_HZ()
+{
+	mprintf("%d", HZ);
+}
+
 void
 mprint_jif(jif)
 	unsigned long jif;
