@@ -12,6 +12,14 @@ const commandtable_t command_sizeof =
 
 static const char head_sizeof[] = "           TYPE NAME    DEC   HEX\n";
 
+PRIVATE void
+prsize(n)
+	int n;
+{
+	mprintf("%20s %6u %5x\n", sizetbl[n].name,
+		sizetbl[n].size, sizetbl[n].size);
+}
+
 PRIVATE addr_t
 sizeof_cmd()
 {
@@ -23,21 +31,34 @@ sizeof_cmd()
 
 	mprintf(head_sizeof);
 	if (argcnt == optind) {
-		for (i = 0; i < sizetbl_size; i++) {
-			mprintf("%20s %6u %5x\n", sizetbl[i].name, sizetbl[i].size, sizetbl[i].size);
-		}
+		for (i = 0; i < sizetbl_size; i++)
+			prsize(i);
 		mprintf(head_sizeof);
-	} else {
-		while (args[optind]) {
-			for (i = 0; i < sizetbl_size; i++) {
-				if (strcmp(args[optind], sizetbl[i].name) == 0)
-					break;
+		return 0;
+	}
+
+	for (; args[optind]; optind++) {
+		int found = 0;
+
+		for (i = 0; i < sizetbl_size; i++) {
+			if (strcmp(sizetbl[i].name, args[optind]) == 0) {
+				prsize(i);
+				found = 1;
+				break;
 			}
-			if (i >= sizetbl_size) {
-				THROWF("unknown type name: %s", args[optind]);
+		}
+		if (found) {
+			prsize(i);
+			continue;
+		}
+		for (i = 0; i < sizetbl_size; i++) {
+			if (strstr(sizetbl[i].name, args[optind])) {
+				prsize(i);
+				found = 1;
 			}
-			mprintf("%20s %6u %5x\n", sizetbl[i].name, sizetbl[i].size, sizetbl[i].size);
-			optind++;
+		}
+		if (!found) {
+			THROWF("unknown type name: %s", args[optind]);
 		}
 	}
 	return 0;
