@@ -14,6 +14,7 @@ const commandtable_t command_stat =
 extern addr_t print_user_struct();
 
 addr_t system_utsname_addr;
+addr_t avenrun_addr;
 extern addr_t jiffies_addr;
 
 addr_t
@@ -24,27 +25,27 @@ print_utsname(addr)
 
 	memread(addr, sizeof(uts), &uts, "system_utsname");
 
-	mprintf("sysname     ");
+	mprintf("sysname      ");
 	mprintstr(uts.sysname, sizeof(uts.sysname));
 	mprintf("\n");
 
-	mprintf("nodename    ");
+	mprintf("nodename     ");
 	mprintstr(uts.nodename, sizeof(uts.nodename));
 	mprintf("\n");
 
-	mprintf("release     ");
+	mprintf("release      ");
 	mprintstr(uts.release, sizeof(uts.release));
 	mprintf("\n");
 
-	mprintf("version     ");
+	mprintf("version      ");
 	mprintstr(uts.version, sizeof(uts.version));
 	mprintf("\n");
 
-	mprintf("machine     ");
+	mprintf("machine      ");
 	mprintstr(uts.machine, sizeof(uts.machine));
 	mprintf("\n");
 
-	mprintf("domainname  ");
+	mprintf("domainname   ");
 	mprintstr(uts.domainname, sizeof(uts.domainname));
 	mprintf("\n");
 
@@ -56,6 +57,7 @@ utsname()
 {
 	int c;
 	unsigned long jiffies;
+	unsigned long avenrun[3];
 
 	while ((c = getopt(argcnt, args, "")) != EOF) {
 		switch (c) {
@@ -70,9 +72,19 @@ utsname()
 	GETADDR(system_utsname);
 	print_utsname(system_utsname_addr);
 
+#ifndef FSHIFT
+#define FSHIFT	11
+#endif /*FSHIFT*/
+	GETADDR(avenrun);
+	memread(avenrun_addr, sizeof(avenrun), avenrun, "avenrun");
+	mprintf("load average %.2f, %.2f, %.2f\n",
+		(double)avenrun[0] / (1<<FSHIFT),
+		(double)avenrun[1] / (1<<FSHIFT),
+		(double)avenrun[2] / (1<<FSHIFT));
+
 	GETADDR(jiffies);
 	memread(jiffies_addr, sizeof(jiffies), &jiffies, "jiffies");
-	mprintf("jiffies     %lx  ", jiffies);
+	mprintf("jiffies      %lx  ", jiffies);
 	mprint_jif(jiffies);
 	mprintf("\n");
 
