@@ -12,7 +12,7 @@ extern addr_t print_xfs_inode();
 
 PRIVATE addr_t xfs_bmbt_rec();
 const commandtable_t command_xfs_bmbt_rec =
-	{"xfs_bmbt_rec", xfs_bmbt_rec, "address", "[XFS] print xfs_bmbt_rec"};
+	{"xfs_bmbt_rec", xfs_bmbt_rec, "[-s] address", "[XFS] print xfs_bmbt_rec"};
 extern addr_t print_xfs_bmbt_rec();
 
 PRIVATE addr_t
@@ -45,9 +45,13 @@ xfs_bmbt_rec()
 	int c;
 	addr_t addr = 0;
 	int size = 16;
+	int swap = 0;
 
-	while ((c = getopt(argcnt, args, "")) != EOF) {
+	while ((c = getopt(argcnt, args, "s")) != EOF) {
 		switch (c) {
+		case 's':
+			swap = 1;
+			break;
 		default:
 			THROW(usage);
 		}
@@ -60,5 +64,5 @@ xfs_bmbt_rec()
 	if (argcnt > optind + 1)
 		size = (int)getvalue(args[optind + 1]);
 
-	return print_xfs_bmbt_rec(addr, size);
+	return print_xfs_bmbt_rec(addr, size, swap);
 }
